==> aws-cdk.aws-cloudfront-origins-1.171.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_cloudfront_origins_HttpOriginProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.originSslProtocols))
            require("@aws-cdk/aws-cloudfront/.warnings.jsii.js")._aws_cdk_aws_cloudfront_OriginSslPolicy(p.originSslProtocols);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_cloudfront_origins_HttpOrigin(p) {
}
function _aws_cdk_aws_cloudfront_origins_LoadBalancerV2OriginProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.originSslProtocols))
            require("@aws-cdk/aws-cloudfront/.warnings.jsii.js")._aws_cdk_aws_cloudfront_OriginSslPolicy(p.originSslProtocols);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_cloudfront_origins_LoadBalancerV2Origin(p) {
}
function _aws_cdk_aws_cloudfront_origins_S3OriginProps(p) {
}
function _aws_cdk_aws_cloudfront_origins_S3Origin(p) {
}
function _aws_cdk_aws_cloudfront_origins_OriginGroupProps(p) {
}
function _aws_cdk_aws_cloudfront_origins_OriginGroup(p) {
}
function _aws_cdk_aws_cloudfront_origins_RestApiOriginProps(p) {
}
function _aws_cdk_aws_cloudfront_origins_RestApiOrigin(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_cloudfront_origins_HttpOriginProps, _aws_cdk_aws_cloudfront_origins_HttpOrigin, _aws_cdk_aws_cloudfront_origins_LoadBalancerV2OriginProps, _aws_cdk_aws_cloudfront_origins_LoadBalancerV2Origin, _aws_cdk_aws_cloudfront_origins_S3OriginProps, _aws_cdk_aws_cloudfront_origins_S3Origin, _aws_cdk_aws_cloudfront_origins_OriginGroupProps, _aws_cdk_aws_cloudfront_origins_OriginGroup, _aws_cdk_aws_cloudfront_origins_RestApiOriginProps, _aws_cdk_aws_cloudfront_origins_RestApiOrigin };

==> aws-cdk.aws-cloudfront-origins-1.181.1.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_cloudfront_origins_HttpOriginProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (p.originSslProtocols != null)
            for (const o of p.originSslProtocols)
                if (!visitedObjects.has(o))
                    require("@aws-cdk/aws-cloudfront/.warnings.jsii.js")._aws_cdk_aws_cloudfront_OriginSslPolicy(o);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_cloudfront_origins_HttpOrigin(p) {
}
function _aws_cdk_aws_cloudfront_origins_LoadBalancerV2OriginProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (p.originSslProtocols != null)
            for (const o of p.originSslProtocols)
                if (!visitedObjects.has(o))
                    require("@aws-cdk/aws-cloudfront/.warnings.jsii.js")._aws_cdk_aws_cloudfront_OriginSslPolicy(o);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_cloudfront_origins_LoadBalancerV2Origin(p) {
}
function _aws_cdk_aws_cloudfront_origins_S3OriginProps(p) {
}
function _aws_cdk_aws_cloudfront_origins_S3Origin(p) {
}
function _aws_cdk_aws_cloudfront_origins_OriginGroupProps(p) {
}
function _aws_cdk_aws_cloudfront_origins_OriginGroup(p) {
}
function _aws_cdk_aws_cloudfront_origins_RestApiOriginProps(p) {
}
function _aws_cdk_aws_cloudfront_origins_RestApiOrigin(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_cloudfront_origins_HttpOriginProps, _aws_cdk_aws_cloudfront_origins_HttpOrigin, _aws_cdk_aws_cloudfront_origins_LoadBalancerV2OriginProps, _aws_cdk_aws_cloudfront_origins_LoadBalancerV2Origin, _aws_cdk_aws_cloudfront_origins_S3OriginProps, _aws_cdk_aws_cloudfront_origins_S3Origin, _aws_cdk_aws_cloudfront_origins_OriginGroupProps, _aws_cdk_aws_cloudfront_origins_OriginGroup, _aws_cdk_aws_cloudfront_origins_RestApiOriginProps, _aws_cdk_aws_cloudfront_origins_RestApiOrigin };
